==> zio-aws-macie2_3-5.17.116.1-sources.jar: zio/aws/macie2/model/UpdateMemberSessionRequest.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class UpdateMemberSessionRequest(
    id: __string,
    status: zio.aws.macie2.model.MacieStatus
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.UpdateMemberSessionRequest = {
    import UpdateMemberSessionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.UpdateMemberSessionRequest
      .builder()
      .id(__string.unwrap(id): java.lang.String)
      .status(status.unwrap)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.UpdateMemberSessionRequest.ReadOnly =
    zio.aws.macie2.model.UpdateMemberSessionRequest.wrap(buildAwsValue())
}
object UpdateMemberSessionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.UpdateMemberSessionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.UpdateMemberSessionRequest =
      zio.aws.macie2.model.UpdateMemberSessionRequest(id, status)
    def id: __string
    def status: zio.aws.macie2.model.MacieStatus
    def getId: ZIO[Any, Nothing, __string] = ZIO.succeed(id)
    def getStatus: ZIO[Any, Nothing, zio.aws.macie2.model.MacieStatus] =
      ZIO.succeed(status)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.UpdateMemberSessionRequest
  ) extends zio.aws.macie2.model.UpdateMemberSessionRequest.ReadOnly {
    override val id: __string =
      zio.aws.macie2.model.primitives.__string(impl.id())
    override val status: zio.aws.macie2.model.MacieStatus =
      zio.aws.macie2.model.MacieStatus.wrap(impl.status())
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.UpdateMemberSessionRequest
  ): zio.aws.macie2.model.UpdateMemberSessionRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-macie2_3-7.21.15.5-sources.jar: zio/aws/macie2/model/UpdateMemberSessionRequest.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class UpdateMemberSessionRequest(
    id: __string,
    status: zio.aws.macie2.model.MacieStatus
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.UpdateMemberSessionRequest = {
    import UpdateMemberSessionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.UpdateMemberSessionRequest
      .builder()
      .id(id: java.lang.String)
      .status(status.unwrap)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.UpdateMemberSessionRequest.ReadOnly =
    zio.aws.macie2.model.UpdateMemberSessionRequest.wrap(buildAwsValue())
}
object UpdateMemberSessionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.UpdateMemberSessionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.UpdateMemberSessionRequest =
      zio.aws.macie2.model.UpdateMemberSessionRequest(id, status)
    def id: __string
    def status: zio.aws.macie2.model.MacieStatus
    def getId: ZIO[Any, Nothing, __string] = ZIO.succeed(id)
    def getStatus: ZIO[Any, Nothing, zio.aws.macie2.model.MacieStatus] =
      ZIO.succeed(status)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.UpdateMemberSessionRequest
  ) extends zio.aws.macie2.model.UpdateMemberSessionRequest.ReadOnly {
    override val id: __string = impl.id(): __string
    override val status: zio.aws.macie2.model.MacieStatus =
      zio.aws.macie2.model.MacieStatus.wrap(impl.status())
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.UpdateMemberSessionRequest
  ): zio.aws.macie2.model.UpdateMemberSessionRequest.ReadOnly = new Wrapper(
    impl
  )
}
